@@ -350,7 +350,6 @@ class MappingCheckOnly(DeserializationMethod):
         data2: dict = data
         item_errors = None
         for key, value in data2.items():
-            assert isinstance(key, str)
             try:
                 self.key_method.deserialize(key)
                 self.value_method.deserialize(value)
@@ -373,7 +372,6 @@ class MappingMethod(DeserializationMethod):
         item_errors = None
         items: dict = {}
         for key, value in data2.items():
-            assert isinstance(key, str)
             try:
                 items[self.key_method.deserialize(key)] = self.value_method.deserialize(
                     value
@@ -870,8 +868,9 @@ class ConversionMethod(DeserializationMethod):
 @dataclass
 class ConversionWithValueErrorMethod(ConversionMethod):
     def deserialize(self, data: Any) -> Any:
+        value = self.method.deserialize(data)
         try:
-            return self.converter(self.method.deserialize(data))
+            return self.converter(value)
         except ValueError as err:
             raise ValidationError(str(err))
 
@@ -893,14 +892,17 @@ class ConversionUnionMethod(DeserializationMethod):
             alternative: ConversionAlternative = self.alternatives[i]
             try:
                 value = alternative.method.deserialize(data)
+            except ValidationError as err:
+                error = merge_errors(error, err)
+                continue
+            try:
+                return alternative.converter(value)
             except ValidationError as err:
                 error = merge_errors(error, err)
             except ValueError as err:
                 if not alternative.value_error:
                     raise
                 error = merge_errors(error, ValidationError(str(err)))
-            else:
-                return alternative.converter(value)
         assert error is not None
         raise error
 
