@@ -2,6 +2,7 @@
 __all__ = ["get_args", "get_origin", "get_type_hints"]
 
 import sys
+from contextlib import suppress
 from types import ModuleType, new_class
 from typing import (  # type: ignore
     Any,
@@ -22,7 +23,7 @@ class _FakeType:
 
 
 if sys.version_info >= (3, 9):  # pragma: no cover
-    from typing import Annotated, TypedDict, get_type_hints, get_origin, get_args
+    from typing import Annotated, TypedDict, get_args, get_origin, get_type_hints
 else:  # pragma: no cover
     try:
         from typing_extensions import Annotated, TypedDict
@@ -51,7 +52,7 @@ else:  # pragma: no cover
         return gth(obj, globalns, localns, include_extras)
 
     try:
-        from typing_extensions import get_origin, get_args
+        from typing_extensions import get_args, get_origin
     except ImportError:
 
         def _assemble_tree(tree: Tuple[Any]) -> Any:
@@ -59,10 +60,10 @@ else:  # pragma: no cover
                 return tree
             else:
                 origin, *args = tree  # type: ignore
-                if origin is Annotated:
-                    return Annotated[(_assemble_tree(args[0]), *args[1])]
-                else:
-                    return origin[tuple(map(_assemble_tree, args))]
+                with suppress(NameError):
+                    if origin is Annotated:
+                        return Annotated[(_assemble_tree(args[0]), *args[1])]
+                return origin[tuple(map(_assemble_tree, args))]
 
         def get_origin(tp):  # type: ignore
             # In Python 3.6: List[Collection[T]][int].__args__ == int != Collection[int]
@@ -96,15 +97,9 @@ else:  # pragma: no cover
         pass
 
 if sys.version_info >= (3, 7):
-    from typing import _collect_type_vars, ForwardRef  # type: ignore
+    from typing import _collect_type_vars  # type: ignore
 else:
-    from typing import _type_vars, _ForwardRef
-
-    _collect_type_vars = _type_vars
-
-    def ForwardRef(arg, is_argument):
-        return _ForwardRef(arg)
-
+    from typing import _type_vars as _collect_type_vars
 
 try:
     from typing import _strip_annotations  # type: ignore
