@@ -17,7 +17,6 @@ from typing import (
     Container,
     Dict,
     Generic,
-    Hashable,
     Iterable,
     Iterator,
     List,
@@ -34,13 +33,7 @@ from typing import (
     cast,
 )
 
-from apischema.types import (
-    AnyType,
-    COLLECTION_TYPES,
-    MAPPING_TYPES,
-    OrderedDict,
-    PRIMITIVE_TYPES,
-)
+from apischema.types import COLLECTION_TYPES, MAPPING_TYPES, PRIMITIVE_TYPES, AnyType
 from apischema.typing import (
     _collect_type_vars,
     generic_mro,
@@ -94,16 +87,8 @@ def opt_or(opt: Optional[T], default: U) -> Union[T, U]:
     return opt if opt is not None else default
 
 
-def to_hashable(data: Union[None, int, float, str, bool, list, dict]) -> Hashable:
-    if isinstance(data, list):
-        return tuple(map(to_hashable, data))
-    if isinstance(data, dict):
-        return tuple(sorted((to_hashable(k), to_hashable(v)) for k, v in data.items()))
-    return data  # type: ignore
-
-
 SNAKE_CASE_REGEX = re.compile(r"_([a-z\d])")
-CAMEL_CASE_REGEX = re.compile(r"[a-z\d]([A-Z])")
+CAMEL_CASE_REGEX = re.compile(r"([a-z\d])([A-Z])")
 
 
 def to_camel_case(s: str) -> str:
@@ -111,7 +96,7 @@ def to_camel_case(s: str) -> str:
 
 
 def to_snake_case(s: str) -> str:
-    return CAMEL_CASE_REGEX.sub(lambda m: "_" + m.group(1).lower(), s)
+    return CAMEL_CASE_REGEX.sub(lambda m: m.group(1) + "_" + m.group(2).lower(), s)
 
 
 def to_pascal_case(s: str) -> str:
@@ -119,9 +104,6 @@ def to_pascal_case(s: str) -> str:
     return camel[0].upper() + camel[1:] if camel else camel
 
 
-MakeDataclassField = Union[Tuple[str, AnyType], Tuple[str, AnyType, Any]]
-
-
 def merge_opts(
     func: Callable[[T, T], T]
 ) -> Callable[[Optional[T], Optional[T]], Optional[T]]:
@@ -192,7 +174,7 @@ def is_subclass(tp: AnyType, base: AnyType) -> bool:
     )
 
 
-def _annotated(tp: AnyType) -> AnyType:
+def no_annotated(tp: AnyType) -> AnyType:
     return get_args(tp)[0] if is_annotated(tp) else tp
 
 
@@ -202,15 +184,15 @@ def get_origin_or_type(tp: AnyType) -> AnyType:
 
 
 def get_origin2(tp: AnyType) -> Optional[Type]:
-    return get_origin(_annotated(tp))
+    return get_origin(no_annotated(tp))
 
 
 def get_args2(tp: AnyType) -> Tuple[AnyType, ...]:
-    return get_args(_annotated(tp))
+    return get_args(no_annotated(tp))
 
 
 def get_origin_or_type2(tp: AnyType) -> AnyType:
-    tp2 = _annotated(tp)
+    tp2 = no_annotated(tp)
     origin = get_origin(tp2)
     return origin if origin is not None else tp2
 
@@ -262,16 +244,6 @@ def replace_builtins(tp: AnyType) -> AnyType:
     return keep_annotations(res, tp)
 
 
-def sort_by_annotations_position(
-    cls: Type, elts: Collection[T], key: Callable[[T], str]
-) -> List[T]:
-    annotations: Dict[str, Any] = OrderedDict()
-    for base in reversed(cls.__mro__):
-        annotations.update(getattr(base, "__annotations__", ()))
-    positions = {key: i for i, key in enumerate(annotations)}
-    return sorted(elts, key=lambda elt: positions.get(key(elt), len(positions)))
-
-
 def stop_signature_abuse() -> NoReturn:
     raise TypeError("Stop signature abuse")
 
@@ -433,11 +405,16 @@ def deprecate_kwargs(
     return decorator
 
 
+CollectionOrPredicate = Union[Collection[T], Callable[[T], bool]]
+
+
 def as_predicate(
-    collection_or_predicate: Union[Collection[T], Callable[[T], bool]]
+    collection_or_predicate: CollectionOrPredicate[T],
 ) -> Callable[[T], bool]:
     if not isinstance(collection_or_predicate, Collection):
         return collection_or_predicate
+    elif not collection_or_predicate:
+        return lambda _: False
     collection = collection_or_predicate
     if not isinstance(collection, AbstractSet):
         with suppress(Exception):
